==> activity-center-api-0.10.27sjq-20191129.021611-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/IdeaPictureDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;

/**
 * 搜狗图片传输实体
 *
 * @author weny.cai
 * @date 2019/1/3 16:52
 **/
public class IdeaPictureDto implements Serializable {

    private Long id;

    private Long ideaId;

    private Long picSpecificId;

    private Integer picH;

    private Integer picW;

    private Integer picType;

    private String picUrl;

    /** 外部id */
    private String outerId;

    /** 外部url */
    private String outerUrl;
    /**
     * 图片大小
     */
    private Integer size;

    /** 素材格式（jpg/png...） */
    private String pictureType;

    /** 图片格式 **/
    private String format;

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getIdeaId() {
        return ideaId;
    }

    public void setIdeaId(Long ideaId) {
        this.ideaId = ideaId;
    }

    public Long getPicSpecificId() {
        return picSpecificId;
    }

    public void setPicSpecificId(Long picSpecificId) {
        this.picSpecificId = picSpecificId;
    }

    public Integer getPicH() {
        return picH;
    }

    public void setPicH(Integer picH) {
        this.picH = picH;
    }

    public Integer getPicW() {
        return picW;
    }

    public void setPicW(Integer picW) {
        this.picW = picW;
    }

    public Integer getPicType() {
        return picType;
    }

    public void setPicType(Integer picType) {
        this.picType = picType;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getOuterId() {
        return outerId;
    }

    public void setOuterId(String outerId) {
        this.outerId = outerId;
    }

    public String getOuterUrl() {
        return outerUrl;
    }

    public void setOuterUrl(String outerUrl) {
        this.outerUrl = outerUrl;
    }

    public String getPictureType() {
        return pictureType;
    }

    public void setPictureType(String pictureType) {
        this.pictureType = pictureType;
    }

    public String getFormat() {
        return format;
    }

    public void setFormat(String format) {
        this.format = format;
    }
}

==> activity-center-api-0.10.39sjq-20191206.022539-2-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/adx/IdeaPictureDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto.adx;

import java.io.Serializable;
import java.math.BigDecimal;

/**
 * 搜狗图片传输实体
 *
 * @author weny.cai
 * @date 2019/1/3 16:52
 **/
public class IdeaPictureDto implements Serializable {

    private Long id;

    private Long ideaId;

    private Long picSpecificId;

    private Integer picH;

    private Integer picW;

    private Integer picType;

    private String picUrl;

    /** 外部id */
    private String outerId;

    /** 外部url */
    private String outerUrl;
    /**
     * 图片大小
     */
    private Integer size;

    /** 素材格式（jpg/png...） */
    private String pictureType;

    /** 图片格式 **/
    private String unit;

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getIdeaId() {
        return ideaId;
    }

    public void setIdeaId(Long ideaId) {
        this.ideaId = ideaId;
    }

    public Long getPicSpecificId() {
        return picSpecificId;
    }

    public void setPicSpecificId(Long picSpecificId) {
        this.picSpecificId = picSpecificId;
    }

    public Integer getPicH() {
        return picH;
    }

    public void setPicH(Integer picH) {
        this.picH = picH;
    }

    public Integer getPicW() {
        return picW;
    }

    public void setPicW(Integer picW) {
        this.picW = picW;
    }

    public Integer getPicType() {
        return picType;
    }

    public void setPicType(Integer picType) {
        this.picType = picType;
    }

    public String getPicUrl() {
        return picUrl;
    }

    public void setPicUrl(String picUrl) {
        this.picUrl = picUrl;
    }

    public String getOuterId() {
        return outerId;
    }

    public void setOuterId(String outerId) {
        this.outerId = outerId;
    }

    public String getOuterUrl() {
        return outerUrl;
    }

    public void setOuterUrl(String outerUrl) {
        this.outerUrl = outerUrl;
    }

    public String getPictureType() {
        return pictureType;
    }

    public void setPictureType(String pictureType) {
        this.pictureType = pictureType;
    }

    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }

}
